@@ -30,7 +30,6 @@ from .payouts_api import PayoutsApi
 from .plans_api import PlansApi
 from .purchase_and_refund_details_api import PurchaseAndRefundDetailsApi
 from .push_funds_api import PushFundsApi
-from .replay_webhooks_api import ReplayWebhooksApi
 from .report_definitions_api import ReportDefinitionsApi
 from .report_downloads_api import ReportDownloadsApi
 from .report_subscriptions_api import ReportSubscriptionsApi
@@ -53,6 +52,7 @@ from .capture_api import CaptureApi
 from .credit_api import CreditApi
 from .invoice_settings_api import InvoiceSettingsApi
 from .invoices_api import InvoicesApi
+from .orders_api import OrdersApi
 from .payments_api import PaymentsApi
 from .refund_api import RefundApi
 from .reversal_api import ReversalApi
